@@ -11,42 +11,42 @@
 # individuals. For the exact contribution history, see the revision
 # history and logs, available at http://genshi.edgewall.org/log/.
 
-import doctest
 import pickle
 import unittest
 
 from genshi import core
 from genshi.core import Markup, Attrs, Namespace, QName, escape, unescape
-from genshi.input import XML, ParseError
-from genshi.compat import StringIO, BytesIO
+from genshi.input import XML
+from genshi.compat import StringIO, BytesIO, IS_PYTHON2
+from genshi.tests.test_utils import doctest_suite
 
 
 class StreamTestCase(unittest.TestCase):
 
     def test_render_utf8(self):
         xml = XML('<li>Über uns</li>')
-        self.assertEqual('<li>Über uns</li>'.encode('utf-8'), xml.render(encoding='utf-8'))
+        self.assertEqual(u'<li>Über uns</li>'.encode('utf-8'), xml.render(encoding='utf-8'))
 
     def test_render_unicode(self):
         xml = XML('<li>Über uns</li>')
-        self.assertEqual('<li>Über uns</li>', xml.render())
-        self.assertEqual('<li>Über uns</li>', xml.render(encoding=None))
+        self.assertEqual(u'<li>Über uns</li>', xml.render())
+        self.assertEqual(u'<li>Über uns</li>', xml.render(encoding=None))
 
     def test_render_ascii(self):
         xml = XML('<li>Über uns</li>')
-        self.assertEqual('<li>&#220;ber uns</li>'.encode('ascii'), xml.render(encoding='ascii'))
+        self.assertEqual(u'<li>&#220;ber uns</li>'.encode('ascii'), xml.render(encoding='ascii'))
 
     def test_render_output_stream_utf8(self):
         xml = XML('<li>Über uns</li>')
         strio = BytesIO()
         self.assertEqual(None, xml.render(encoding='utf-8', out=strio))
-        self.assertEqual('<li>Über uns</li>'.encode('utf-8'), strio.getvalue())
+        self.assertEqual(u'<li>Über uns</li>'.encode('utf-8'), strio.getvalue())
 
     def test_render_output_stream_unicode(self):
         xml = XML('<li>Über uns</li>')
         strio = StringIO()
         self.assertEqual(None, xml.render(encoding=None, out=strio))
-        self.assertEqual('<li>Über uns</li>', strio.getvalue())
+        self.assertEqual(u'<li>Über uns</li>', strio.getvalue())
 
     def test_pickle(self):
         xml = XML('<li>Foo</li>')
@@ -60,13 +60,14 @@ class StreamTestCase(unittest.TestCase):
 class MarkupTestCase(unittest.TestCase):
 
     def test_new_with_encoding(self):
-        markup = Markup('Döner'.encode('utf-8'), encoding='utf-8')
+        markup = Markup(u'Döner'.encode('utf-8'), encoding='utf-8')
         # mimic Markup.__repr__ when constructing output for Python 2/3 compatibility
-        self.assertEqual("<Markup %r>" % 'D\u00f6ner', repr(markup))
+        self.assertEqual("<Markup %r>" % u'D\u00f6ner', repr(markup))
 
     def test_repr(self):
         markup = Markup('foo')
-        self.assertEqual("<Markup 'foo'>", repr(markup))
+        expected_foo = "u'foo'" if IS_PYTHON2 else "'foo'"
+        self.assertEqual("<Markup %s>" % expected_foo, repr(markup))
 
     def test_escape(self):
         markup = escape('<b>"&"</b>')
@@ -169,7 +170,8 @@ class MarkupTestCase(unittest.TestCase):
         buf = BytesIO()
         pickle.dump(markup, buf, 2)
         buf.seek(0)
-        self.assertEqual("<Markup 'foo'>", repr(pickle.load(buf)))
+        expected_foo = "u'foo'" if IS_PYTHON2 else "'foo'"
+        self.assertEqual("<Markup %s>" % expected_foo, repr(pickle.load(buf)))
 
 
 class AttrsTestCase(unittest.TestCase):
@@ -184,8 +186,8 @@ class AttrsTestCase(unittest.TestCase):
                           repr(unpickled))
 
     def test_non_ascii(self):
-        attrs_tuple = Attrs([("attr1", "föö"), ("attr2", "bär")]).totuple()
-        self.assertEqual('fööbär', attrs_tuple[1])
+        attrs_tuple = Attrs([("attr1", u"föö"), ("attr2", u"bär")]).totuple()
+        self.assertEqual(u'fööbär', attrs_tuple[1])
 
 
 class NamespaceTestCase(unittest.TestCase):
@@ -199,7 +201,7 @@ class NamespaceTestCase(unittest.TestCase):
         self.assertEqual(eval(repr(ns)), ns)
 
     def test_repr_eval_non_ascii(self):
-        ns = Namespace('http://www.example.org/nämespäcé')
+        ns = Namespace(u'http://www.example.org/nämespäcé')
         self.assertEqual(eval(repr(ns)), ns)
 
     def test_pickle(self):
@@ -236,7 +238,7 @@ class QNameTestCase(unittest.TestCase):
         self.assertEqual(eval(repr(qn)), qn)
 
     def test_repr_eval_non_ascii(self):
-        qn = QName('élem')
+        qn = QName(u'élem')
         self.assertEqual(eval(repr(qn)), qn)
 
     def test_leading_curly_brace(self):
@@ -254,12 +256,12 @@ class QNameTestCase(unittest.TestCase):
 
 def suite():
     suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(StreamTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(MarkupTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(NamespaceTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(AttrsTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(QNameTestCase, 'test'))
-    suite.addTest(doctest.DocTestSuite(core))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(StreamTestCase))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(MarkupTestCase))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(NamespaceTestCase))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(AttrsTestCase))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(QNameTestCase))
+    suite.addTest(doctest_suite(core))
     return suite
 
 if __name__ == '__main__':
