@@ -301,6 +301,19 @@ class TranslatorTestCase(unittest.TestCase):
           <span title="Voh">...</span>
         </html>""", tmpl.generate().render())
 
+    def test_translate_nested_directives(self):
+        html = """<html xmlns:py="http://genshi.edgewall.org/">
+            <py:with vars="x = 'test'"><py:if test="x">
+            </py:if></py:with>
+        </html>"""
+        tmpl = MarkupTemplate(html)
+        raw = tmpl.generate().render()
+        tmpl = MarkupTemplate(html)
+        translator = Translator(DummyTranslations())
+        translator.setup(tmpl)
+        translated = tmpl.generate().render()
+        self.assertEqual(raw, translated)
+
 
 class MsgDirectiveTestCase(unittest.TestCase):
 
@@ -2190,12 +2203,12 @@ class ContextDirectiveTestCase(unittest.TestCase):
 def suite():
     suite = unittest.TestSuite()
     suite.addTest(doctest_suite(Translator.__module__))
-    suite.addTest(unittest.makeSuite(TranslatorTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(MsgDirectiveTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(ChooseDirectiveTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(DomainDirectiveTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(ExtractTestCase, 'test'))
-    suite.addTest(unittest.makeSuite(ContextDirectiveTestCase, 'test'))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(TranslatorTestCase))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(MsgDirectiveTestCase))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(ChooseDirectiveTestCase))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(DomainDirectiveTestCase))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(ExtractTestCase))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(ContextDirectiveTestCase))
     return suite
 
 if __name__ == '__main__':
